@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -136,16 +136,18 @@ void AbstractImportExportJob::overwriteDirectory(const QString &path, const KArc
 {
     if (QDir(path).exists()) {
         if (overwriteDirectoryMessageBox(path)) {
-            const auto *dirEntry = static_cast<const KArchiveDirectory *>(entry);
-            if (!dirEntry->copyTo(path)) {
-                qCWarning(PIMDATAEXPORTERCORE_LOG) << "directory cannot overwrite to " << path;
-            }
+          const auto dirEntry = static_cast<const KArchiveDirectory *>(entry);
+          if (!dirEntry->copyTo(path)) {
+            qCWarning(PIMDATAEXPORTERCORE_LOG)
+                << "directory cannot overwrite to " << path;
+          }
         }
     } else {
-        const auto *dirEntry = static_cast<const KArchiveDirectory *>(entry);
-        if (dirEntry->copyTo(path)) {
-            qCWarning(PIMDATAEXPORTERCORE_LOG) << "directory cannot overwrite to " << path;
-        }
+      const auto dirEntry = static_cast<const KArchiveDirectory *>(entry);
+      if (dirEntry->copyTo(path)) {
+        qCWarning(PIMDATAEXPORTERCORE_LOG)
+            << "directory cannot overwrite to " << path;
+      }
     }
 }
 
@@ -171,26 +173,29 @@ void AbstractImportExportJob::storeArchiveInfoResources(const KArchiveDirectory
     for (const QString &entryName : lst) {
         const KArchiveEntry *entry = dir->entry(entryName);
         if (entry && entry->isDirectory()) {
-            const auto *resourceDir = static_cast<const KArchiveDirectory *>(entry);
-            const QStringList lst = resourceDir->entries();
+          const auto resourceDir =
+              static_cast<const KArchiveDirectory *>(entry);
+          const QStringList lst = resourceDir->entries();
 
-            if (lst.count() >= 2) {
-                const QString archPath(prefix + QLatin1Char('/') + entryName + QLatin1Char('/'));
-                ResourceFiles files;
-                for (const QString &name : lst) {
-                    if (isAConfigFile(name)) {
-                        files.akonadiConfigFile = archPath + name;
-                    } else if (name.startsWith(Utils::prefixAkonadiConfigFile())) {
-                        files.akonadiAgentConfigFile = archPath + name;
-                    } else {
-                        files.akonadiResources = archPath + name;
-                    }
-                }
-                files.debug();
-                mListResourceFile.append(files);
-            } else {
-                qCWarning(PIMDATAEXPORTERCORE_LOG) << " Problem in archive. number of file " << lst.count();
+          if (lst.count() >= 2) {
+            const QString archPath(prefix + QLatin1Char('/') + entryName +
+                                   QLatin1Char('/'));
+            ResourceFiles files;
+            for (const QString &name : lst) {
+              if (isAConfigFile(name)) {
+                files.akonadiConfigFile = archPath + name;
+              } else if (name.startsWith(Utils::prefixAkonadiConfigFile())) {
+                files.akonadiAgentConfigFile = archPath + name;
+              } else {
+                files.akonadiResources = archPath + name;
+              }
             }
+            files.debug();
+            mListResourceFile.append(files);
+          } else {
+            qCWarning(PIMDATAEXPORTERCORE_LOG)
+                << " Problem in archive. number of file " << lst.count();
+          }
         }
     }
     std::sort(mListResourceFile.begin(), mListResourceFile.end());
@@ -198,7 +203,7 @@ void AbstractImportExportJob::storeArchiveInfoResources(const KArchiveDirectory
 
 bool AbstractImportExportJob::isAConfigFile(const QString &name) const
 {
-    Q_UNUSED(name);
+    Q_UNUSED(name)
     //Redefine in subclass
     return true;
 }
@@ -261,10 +266,10 @@ void AbstractImportExportJob::initializeImportJob()
 
 void AbstractImportExportJob::copyToDirectory(const KArchiveEntry *entry, const QString &dest)
 {
-    const auto *subfolderDir = static_cast<const KArchiveDirectory *>(entry);
-    if (!subfolderDir->copyTo(dest)) {
-        qCDebug(PIMDATAEXPORTERCORE_LOG) << "directory cannot copy to " << dest;
-    }
+  const auto subfolderDir = static_cast<const KArchiveDirectory *>(entry);
+  if (!subfolderDir->copyTo(dest)) {
+    qCDebug(PIMDATAEXPORTERCORE_LOG) << "directory cannot copy to " << dest;
+  }
     Q_EMIT info(i18n("\"%1\" was copied.", dest));
 }
 
@@ -302,13 +307,15 @@ void AbstractImportExportJob::copyToFile(const KArchiveFile *archivefile, const
 
 void AbstractImportExportJob::backupResourceFile(const QString &identifier, const QString &defaultPath)
 {
-    auto *job = new BackupResourceFileJobImpl(this);
-    job->setDefaultPath(defaultPath);
-    job->setIdentifier(identifier);
-    job->setZip(archive());
-    connect(job, &BackupResourceFileJobImpl::error, this, &AbstractImportExportJob::error);
-    connect(job, &BackupResourceFileJobImpl::info, this, &AbstractImportExportJob::info);
-    job->start();
+  auto job = new BackupResourceFileJobImpl(this);
+  job->setDefaultPath(defaultPath);
+  job->setIdentifier(identifier);
+  job->setZip(archive());
+  connect(job, &BackupResourceFileJobImpl::error, this,
+          &AbstractImportExportJob::error);
+  connect(job, &BackupResourceFileJobImpl::info, this,
+          &AbstractImportExportJob::info);
+  job->start();
 }
 
 QStringList AbstractImportExportJob::restoreResourceFile(const QString &resourceBaseName, const QString &defaultPath, const QString &storePath, bool overwriteResources)
@@ -327,10 +334,13 @@ QStringList AbstractImportExportJob::restoreResourceFile(const QString &resource
             if (value.akonadiConfigFile.contains(resourceBaseName + QLatin1Char('_'))) {
                 const KArchiveEntry *fileResouceEntry = mArchiveDirectory->entry(value.akonadiConfigFile);
                 if (fileResouceEntry && fileResouceEntry->isFile()) {
-                    const auto *file = static_cast<const KArchiveFile *>(fileResouceEntry);
-                    if (!file->copyTo(copyToDirName)) {
-                        qCWarning(PIMDATAEXPORTERCORE_LOG) << "file " << value.akonadiConfigFile << " can not copy to " << copyToDirName;
-                    }
+                  const auto file =
+                      static_cast<const KArchiveFile *>(fileResouceEntry);
+                  if (!file->copyTo(copyToDirName)) {
+                    qCWarning(PIMDATAEXPORTERCORE_LOG)
+                        << "file " << value.akonadiConfigFile
+                        << " can not copy to " << copyToDirName;
+                  }
                     QString resourceName(file->name());
 
                     QString filename(file->name());
@@ -343,10 +353,13 @@ QStringList AbstractImportExportJob::restoreResourceFile(const QString &resource
                     const QString dataFile = value.akonadiResources;
                     const KArchiveEntry *dataResouceEntry = mArchiveDirectory->entry(dataFile);
                     if (dataResouceEntry->isFile()) {
-                        const auto *file = static_cast<const KArchiveFile *>(dataResouceEntry);
-                        if (!file->copyTo(newUrl)) {
-                            qCWarning(PIMDATAEXPORTERCORE_LOG) << "file " << dataFile << " can not copy to " << newUrl;
-                        }
+                      const auto file =
+                          static_cast<const KArchiveFile *>(dataResouceEntry);
+                      if (!file->copyTo(newUrl)) {
+                        qCWarning(PIMDATAEXPORTERCORE_LOG)
+                            << "file " << dataFile << " can not copy to "
+                            << newUrl;
+                      }
                     }
                     settings.insert(QStringLiteral("Path"), newUrl);
 
@@ -354,11 +367,13 @@ QStringList AbstractImportExportJob::restoreResourceFile(const QString &resource
                     if (!agentConfigFile.isEmpty()) {
                         const KArchiveEntry *akonadiAgentConfigEntry = mArchiveDirectory->entry(agentConfigFile);
                         if (akonadiAgentConfigEntry->isFile()) {
-                            const auto *file = static_cast<const KArchiveFile *>(akonadiAgentConfigEntry);
-                            file->copyTo(copyToDirName);
-                            resourceName = file->name();
-                            const QString configPath = copyToDirName + QLatin1Char('/') + resourceName;
-                            filename = Utils::akonadiAgentName(configPath);
+                          const auto file = static_cast<const KArchiveFile *>(
+                              akonadiAgentConfigEntry);
+                          file->copyTo(copyToDirName);
+                          resourceName = file->name();
+                          const QString configPath =
+                              copyToDirName + QLatin1Char('/') + resourceName;
+                          filename = Utils::akonadiAgentName(configPath);
                         }
                     }
 
@@ -412,11 +427,13 @@ void AbstractImportExportJob::extractZipFile(const KArchiveFile *file, const QSt
                 const KArchiveEntry *entry = zipDir->entry(entryName);
                 if (entry) {
                     if (entry->isDirectory()) {
-                        const auto *dir = static_cast<const KArchiveDirectory *>(entry);
-                        dir->copyTo(destination + QLatin1Char('/') + dir->name(), true);
+                      const auto dir =
+                          static_cast<const KArchiveDirectory *>(entry);
+                      dir->copyTo(destination + QLatin1Char('/') + dir->name(),
+                                  true);
                     } else if (entry->isFile()) {
-                        const auto *dir = static_cast<const KArchiveFile *>(entry);
-                        dir->copyTo(destination);
+                      const auto dir = static_cast<const KArchiveFile *>(entry);
+                      dir->copyTo(destination);
                     }
                 }
                 qApp->processEvents();
@@ -437,15 +454,22 @@ void AbstractImportExportJob::restoreUiRcFile(const QString &configNameStr, cons
 {
     const KArchiveEntry *configNameentry = mArchiveDirectory->entry(Utils::configsPath() + configNameStr);
     if (configNameentry && configNameentry->isFile()) {
-        const auto *configNameconfiguration = static_cast<const KArchiveFile *>(configNameentry);
-        const QString configNamerc = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kxmlgui5/") + applicationName + QLatin1Char('/') + configNameStr;
-        if (QFileInfo::exists(configNamerc)) {
-            if (overwriteConfigMessageBox(configNameStr)) {
-                copyToFile(configNameconfiguration, configNamerc, configNameStr, Utils::configsPath());
-            }
-        } else {
-            copyToFile(configNameconfiguration, configNamerc, configNameStr, Utils::configsPath());
+      const auto configNameconfiguration =
+          static_cast<const KArchiveFile *>(configNameentry);
+      const QString configNamerc = QStandardPaths::writableLocation(
+                                       QStandardPaths::GenericDataLocation) +
+                                   QLatin1String("/kxmlgui5/") +
+                                   applicationName + QLatin1Char('/') +
+                                   configNameStr;
+      if (QFileInfo::exists(configNamerc)) {
+        if (overwriteConfigMessageBox(configNameStr)) {
+          copyToFile(configNameconfiguration, configNamerc, configNameStr,
+                     Utils::configsPath());
         }
+      } else {
+        copyToFile(configNameconfiguration, configNamerc, configNameStr,
+                   Utils::configsPath());
+      }
     }
 }
 
@@ -453,16 +477,21 @@ void AbstractImportExportJob::restoreConfigFile(const QString &configNameStr)
 {
     const KArchiveEntry *configNameentry = mArchiveDirectory->entry(Utils::configsPath() + configNameStr);
     if (configNameentry && configNameentry->isFile()) {
-        const auto *configNameconfiguration = static_cast<const KArchiveFile *>(configNameentry);
-        const QString configNamerc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + configNameStr;
-        if (QFileInfo::exists(configNamerc)) {
-            //TODO 4.12 allow to merge config.
-            if (overwriteConfigMessageBox(configNameStr)) {
-                copyToFile(configNameconfiguration, configNamerc, configNameStr, Utils::configsPath());
-            }
-        } else {
-            copyToFile(configNameconfiguration, configNamerc, configNameStr, Utils::configsPath());
+      const auto configNameconfiguration =
+          static_cast<const KArchiveFile *>(configNameentry);
+      const QString configNamerc =
+          QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) +
+          QLatin1Char('/') + configNameStr;
+      if (QFileInfo::exists(configNamerc)) {
+        // TODO 4.12 allow to merge config.
+        if (overwriteConfigMessageBox(configNameStr)) {
+          copyToFile(configNameconfiguration, configNamerc, configNameStr,
+                     Utils::configsPath());
         }
+      } else {
+        copyToFile(configNameconfiguration, configNamerc, configNameStr,
+                   Utils::configsPath());
+      }
     }
 }
 
@@ -506,7 +535,7 @@ void AbstractImportExportJob::slotNextStep()
 void AbstractImportExportJob::startSynchronizeResources(const QStringList &listResourceToSync)
 {
     Q_EMIT info(i18n("Start synchronizing..."));
-    auto *job = new SynchronizeResourceJob(this);
+    auto job = new SynchronizeResourceJob(this);
     job->setListResources(listResourceToSync);
     connect(job, &SynchronizeResourceJob::synchronizationFinished, this, &AbstractImportExportJob::slotAllResourceSynchronized);
     connect(job, &SynchronizeResourceJob::synchronizationInstanceDone, this, &AbstractImportExportJob::slotSynchronizeInstanceDone);
@@ -553,23 +582,29 @@ void AbstractImportExportJob::importDataSubdirectory(const QString &subdirectory
 {
     const KArchiveEntry *themeEntry = mArchiveDirectory->entry(Utils::dataPath() + subdirectoryRelativePath);
     if (themeEntry && themeEntry->isDirectory()) {
-        const auto *themeDir = static_cast<const KArchiveDirectory *>(themeEntry);
-        const QStringList lst = themeDir->entries();
-        for (const QString &entryName : lst) {
-            const KArchiveEntry *entry = themeDir->entry(entryName);
-            if (entry && entry->isDirectory()) {
-                QString subFolderName = entryName;
-                const QString topLevelPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + subdirectoryRelativePath;
-                QDir themeDirectory(topLevelPath + QStringLiteral("/%1").arg(entryName));
-                int i = 1;
-                while (themeDirectory.exists()) {
-                    subFolderName = entryName + QStringLiteral("_%1").arg(i);
-                    themeDirectory = QDir(topLevelPath + QStringLiteral("/%1").arg(subFolderName));
-                    ++i;
-                }
-                copyToDirectory(entry, topLevelPath + QStringLiteral("/%1").arg(subFolderName));
-            }
+      const auto themeDir = static_cast<const KArchiveDirectory *>(themeEntry);
+      const QStringList lst = themeDir->entries();
+      for (const QString &entryName : lst) {
+        const KArchiveEntry *entry = themeDir->entry(entryName);
+        if (entry && entry->isDirectory()) {
+          QString subFolderName = entryName;
+          const QString topLevelPath =
+              QStandardPaths::writableLocation(
+                  QStandardPaths::GenericDataLocation) +
+              QLatin1Char('/') + subdirectoryRelativePath;
+          QDir themeDirectory(topLevelPath +
+                              QStringLiteral("/%1").arg(entryName));
+          int i = 1;
+          while (themeDirectory.exists()) {
+            subFolderName = entryName + QStringLiteral("_%1").arg(i);
+            themeDirectory =
+                QDir(topLevelPath + QStringLiteral("/%1").arg(subFolderName));
+            ++i;
+          }
+          copyToDirectory(entry, topLevelPath +
+                                     QStringLiteral("/%1").arg(subFolderName));
         }
+      }
     }
 }
 
