@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -29,7 +29,7 @@ class PIMDATAEXPORTER_EXPORT AbstractImportExportJob : public QObject
     Q_OBJECT
 public:
     explicit AbstractImportExportJob(QObject *parent, ArchiveStorage *archiveStorage, Utils::StoredTypes typeSelected, int numberOfStep);
-    ~AbstractImportExportJob();
+    ~AbstractImportExportJob() override;
 
     virtual void start() = 0;
 
