@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -38,7 +38,8 @@ void ImportNotesJobInterfaceTest::importNote()
     file->setPathConfig(fullTestPath);
     file->setExtractPath(QDir::tempPath() + testPath);
     file->setExcludePath(Utils::notePath());
-    auto *impl = new ImportNotesJobInterfaceTestImpl(this, options, file->archiveStorage(), 1);
+    auto impl = new ImportNotesJobInterfaceTestImpl(this, options,
+                                                    file->archiveStorage(), 1);
     impl->setPathConfig(file->pathConfig());
     impl->setExistingPathConfig(fullTestPath + QStringLiteral("/existingconfig/"));
     file->setAbstractImportExportJob(impl);
