@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ class PIMDATAEXPORTER_EXPORT BackupResourceFileJobImpl : public BackupResourceFi
     Q_OBJECT
 public:
     explicit BackupResourceFileJobImpl(QObject *parent = nullptr);
-    ~BackupResourceFileJobImpl();
+    ~BackupResourceFileJobImpl() override;
 
     Q_REQUIRED_RESULT QString resourcePath(const QString &identifier) const override;
 };
