@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class StoreResourceJob : public QObject
     Q_OBJECT
 public:
     explicit StoreResourceJob(QObject *parent = nullptr);
-    ~StoreResourceJob();
+    ~StoreResourceJob() override;
 
     void start();
 
