@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ class PimDataExporterConfigureDialog : public KPageDialog
     Q_OBJECT
 public:
     explicit PimDataExporterConfigureDialog(QWidget *parent = nullptr);
-    ~PimDataExporterConfigureDialog();
+    ~PimDataExporterConfigureDialog() override;
 
 private:
     void slotAccepted();
