@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ class SelectionTypeDialog : public QDialog
     Q_OBJECT
 public:
     explicit SelectionTypeDialog(bool backupData, QWidget *parent = nullptr);
-    ~SelectionTypeDialog();
+    ~SelectionTypeDialog() override;
 
     Q_REQUIRED_RESULT QHash<Utils::AppsType, Utils::importExportParameters> storedType() const;
 
