@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,7 +17,7 @@ class FullSynchronizeResourcesJob : public QObject
     Q_OBJECT
 public:
     explicit FullSynchronizeResourcesJob(QObject *parent = nullptr);
-    ~FullSynchronizeResourcesJob();
+    ~FullSynchronizeResourcesJob() override;
 
     void setResources(const QStringList &lst);
 
