@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,9 +13,9 @@
 LogWidget::LogWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *layout = new QHBoxLayout(this);
-    mCustomLogWidget = new PimCommon::CustomLogWidget(this);
-    layout->addWidget(mCustomLogWidget);
+  auto layout = new QHBoxLayout(this);
+  mCustomLogWidget = new PimCommon::CustomLogWidget(this);
+  layout->addWidget(mCustomLogWidget);
 }
 
 LogWidget::~LogWidget()
