@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,7 +17,7 @@ class LogWidget : public QWidget
     Q_OBJECT
 public:
     explicit LogWidget(QWidget *parent);
-    ~LogWidget();
+    ~LogWidget() override;
 
     void addInfoLogEntry(const QString &log);
     void addErrorLogEntry(const QString &log);
